@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,7 +40,9 @@ void add_foods(int label)
 {
 struct food *food_ptr = &food_root;
 char key[121];
-int c, delfood, junk, likeit = 'n', dupname = 0, resname = 0;
+char buff[128];
+char *token;
+int c, modfood, junk, likeit = 'n', dupname = 0, resname = 0;
 float ratio, one = 1, servings = 0, savegrams, savewater;
 key[0] = '\0';
 key_clean();
@@ -136,7 +138,8 @@ for ( ; ; )
       junk = get_char();
       if (junk == 'n' || junk == 'N')
        {
-       while (recipe_root.next != NULL) delete_recipe_food(1);
+       token = NULL;
+       while (recipe_root.next != NULL) modify_recipe_food(1,token);
        return;
        }
       }
@@ -160,7 +163,8 @@ for ( ; ; )
       for (c = 0; c < NUTRIENT_COUNT; c++) food_work.nutrient[c] += (food_ptr->nutrient[c] * food_ptr->grams / 100); 
       food_work.grams += food_ptr->grams;
       }
-     while (recipe_root.next != NULL && ! label) delete_recipe_food(1);
+     token = NULL;
+     while (recipe_root.next != NULL && ! label) modify_recipe_food(1,token);
      if (label) servings = 1;
      for (c = 0; c < NUTRIENT_COUNT; c++) if (food_work.nutrient[c] < 0) food_work.nutrient[c] = NoData; 
      while (servings <= 0)
@@ -251,9 +255,12 @@ for ( ; ; )
      }
     }
    }
-  delfood = atoi(key);
-  if (strcmp(key,"") == 0 || delfood == 0) break;
-  delete_recipe_food(delfood);
+  modfood = atoi(key);
+  strncpy(buff,key,128);
+  token = strtok(buff, ", ");
+  token = strtok(NULL,", ");
+  if (strcmp(key,"") == 0 || modfood == 0) break;
+  modify_recipe_food(modfood,token);
   strcpy(key,"");
   }
  ratio = -383838;
@@ -442,7 +449,7 @@ for ( ; ; )
  get_nut_value(&tempfloat);
  if (options.screen == 0 && (nutnum != FAMS && nutnum != FAPU && nutnum != OMEGA6 && nutnum != LA && nutnum != AA && nutnum != OMEGA3 && nutnum != ALA && nutnum != EPA && nutnum != DHA && nutnum != CHO_NONFIB)) tempfloat = tempfloat / 100 * DVBase[nutnum];
  food_work.nutrient[nutnum] = tempfloat;
- if (nutnum == VITE) food_work.nutrient[TOCPHA] = tempfloat;
+ if (nutnum == VITE) food_work.nutrient[TOCPHA] = tempfloat * 2/3;
  if (nutnum == LA  ) food_work.nutrient[F18D2] = tempfloat;
  if (nutnum == AA  ) food_work.nutrient[F20D4] = tempfloat;
  if (nutnum == ALA ) food_work.nutrient[F18D3] = tempfloat;
@@ -492,6 +499,7 @@ int i, j, savegramoption;
 int gt0dvnuts[DV_COUNT];
 float gt0dvnutfactors[DV_COUNT];
 int nutcount = 0;
+char *token;
 
 struct food *recipe_ptr;
 struct food *foodlist[2 * DV_COUNT];
@@ -535,7 +543,8 @@ for (i = 0; i < NUTRIENT_COUNT; i++)
  recipe_root.nutrient[i] = 0;
  }
 compute_derived_fields(&food_work);
-while (recipe_root.next != NULL) delete_recipe_food(1);
+token = NULL;
+while (recipe_root.next != NULL) modify_recipe_food(1,token);
 }
 
 void solve_it(int prevquantum, int quanta, int foodno, int foodcount, int nutcount)
