@@ -193,13 +193,13 @@ while (max > 0)
   if ( !options.locknuts[PROCNT] ) options.fatprotratio = 0 ;
   if ( !options.locknuts[CHOCDF] ) options.abnuts[CHOCDF] = 0 ;
   if ( !options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG];
-  if ( !options.locknuts[ENERC_KCAL])
+  if ( !options.locknuts[ENERC_KCAL] && !options.autocal)
    {
    newcal = food_work.nutrient[ENERC_KCAL];
    if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
    if ( !options.locknuts[CHOCDF]) options.pccarb = food_work.nutrient[CHO_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
    }
-  if (  options.locknuts[ENERC_KCAL])
+  if (  options.locknuts[ENERC_KCAL] || options.autocal)
    {
    newcal = DV[ENERC_KCAL];
    if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / DV[ENERC_KCAL] * 100;
@@ -227,7 +227,7 @@ while (max > 0)
       DVMap[count+1] == CHOLE || DVMap[count+1] == OMEGA6 ||
       DVMap[count+1] == CHO_NONFIB || DVMap[count+1] == OMEGA3 ||
       DVMap[count+1] == CHOCDF || 
-      food_work.nutrient[DVMap[count+1]] >= DV[DVMap[count+1]]) deficpct[count] = 0;
+      food_work.nutrient[DVMap[count+1]] / DV[DVMap[count+1]] >= .9999) deficpct[count] = 0;
    else 
     {
     deficnuts++;
