@@ -131,12 +131,12 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 9;
-DVBase[AA] = 0.25;
+DVBase[LA] = 4.44;
+DVBase[AA] = 0.2;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 2.5;
-DVBase[EPA] = 0.25;
-DVBase[DHA] = 0.25;
+DVBase[ALA] = 2.22;
+DVBase[EPA] = 0.33;
+DVBase[DHA] = 0.33;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
 DVBase[FAPU] = DVBase[OMEGA6] + DVBase[OMEGA3];
 DVBase[FAMS] = 61.5 - DVBase[FASAT] - DVBase[FAPU];
@@ -585,6 +585,7 @@ void food_display(FILE *fp)
 {
 int i;
 float pctfat = 0, pctcarb = 0, pctprot = 0;
+float p3, p6, h3, h6, o, calories;
 char carbprotfat[9];
 if (food_work.nutrient[ENERC_KCAL] > 0.05)
  {
@@ -640,7 +641,18 @@ switch (options.screen)
  food_display_line(fp,ScreenMap[options.screen][i],0,0,0,4);
  food_display_line(fp,ScreenMap[options.screen][i+16],0,1,0,0);
  food_display_line(fp,ScreenMap[options.screen][13],0,0,0,0);
- food_display_line(fp,ScreenMap[options.screen][13+16],0,1,0,0);
+ if (!options.n6hufaspec) food_display_line(fp,ScreenMap[options.screen][13+16],0,1,0,0);
+ if (options.n6hufaspec)
+  {
+  food_display_line(fp,ScreenMap[options.screen][13+16],0,0,0,0);
+  calories = food_work.nutrient[ENERC_KCAL];
+  p3 = 902 * food_work.nutrient[ALA] / calories;
+  p6 = 902 * food_work.nutrient[LA] / calories;
+  h3 = 902 * (food_work.nutrient[EPA] + food_work.nutrient[DHA]) / calories;
+  h6 = 902 * food_work.nutrient[AA] / calories;
+  o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / calories;
+  fprintf(fp,"Omega-6 HUFA     %5.1f%%\n",n6hufa(p3,p6,h3,h6,o,calories));
+  }
  break;
  case 2 :
  fprintf(fp,"%-27s","Carbohydrates");
@@ -751,7 +763,18 @@ switch (options.screen)
  food_display_line(fp,ScreenMap[options.screen][i],1,0,0,4);
  food_display_line(fp,ScreenMap[options.screen][i+16],1,1,0,0);
  food_display_line(fp,ScreenMap[options.screen][13],1,0,0,0);
- food_display_line(fp,ScreenMap[options.screen][13+16],1,1,0,0);
+ if (!options.n6hufaspec) food_display_line(fp,ScreenMap[options.screen][13+16],1,1,0,0);
+ if (options.n6hufaspec)
+  {
+  food_display_line(fp,ScreenMap[options.screen][13+16],1,0,0,0);
+  calories = food_work.nutrient[ENERC_KCAL];
+  p3 = 902 * food_work.nutrient[ALA] / calories;
+  p6 = 902 * food_work.nutrient[LA] / calories;
+  h3 = 902 * (food_work.nutrient[EPA] + food_work.nutrient[DHA]) / calories;
+  h6 = 902 * food_work.nutrient[AA] / calories;
+  o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / calories;
+  fprintf(fp,"Omega-6 HUFA     %5.0f%%\n",n6hufa(p3,p6,h3,h6,o,calories));
+  }
  break;
  }
 }
@@ -940,3 +963,17 @@ strncat(buffer,food_ptr->unit,50);
 buffer[49] = '\0';
 return buffer;
 }
+
+float n6hufa(float p3, float p6, float h3, float h6, float o, float calories)
+{
+float pc6 = .0441, pc3 = .0555, co = 5, ks = .175, hi3 = .005, hc6 = .7, hc3 = 3;
+float answer;
+/*
+printf("%f %f %f %f %f %f\n",p3,p6,h3,h6,o,calories);
+exit(0);
+*/  
+answer = 100 / (1 + pc6/p6 * (1 + p3/pc3 + h3/hi3 + o/co + p6/ks)) + 100 / (1 + hc6/h6 * (1 + h3/hc3));
+if (answer <= 90 && answer >= 15) return answer;
+if (answer > 90) return 90;
+else return 15;
+}
