@@ -126,12 +126,14 @@ float temp, lastsetting;
 lastsetting = options.abnuts[FAPU];
 header("NUT:  Essential Fats Absolute Amount");
 spacer(0);
+options.n6hufaspec = 0;
 printf("\nEnter absolute amount of EFAs in grams (just <enter> for default):  ");
 get_string(buf,127);
 options.abnuts[FAPU] = atof(buf);
 options.locknuts[FAPU] = 1;
 if ( options.abnuts[FAPU] < 0 ) 
  {
+ if (options.abnuts[FAPU] == -1) options.n6hufaspec = 1;
  options.abnuts[FAPU] = 0;
  options.locknuts[FAPU] = 0;
  }
@@ -444,12 +446,13 @@ if (options.fatprotratio > 0 && (options.abnuts[PROCNT] > 0 || options.pcprotein
  temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[FAT] * options.fatcalpergm) / DV[ENERC_KCAL];
  DV[CHOCDF] = temp * DV[ENERC_KCAL] / options.carbcalpergm;
  }
-if (options.fatprotratio <= 0 && buf != 1)
+if (options.fatprotratio <= 0 && (DV[PROCNT] != DVBase[PROCNT] || DV[CHOCDF] != DVBase[CHOCDF]))
  {
  temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
  DV[FAT] = temp * DV[ENERC_KCAL] / options.fatcalpergm;
  }
 DV[FAMS] = options.fattyacidfactor * DV[FAT] - DV[FASAT] - DV[FAPU];
+if (analflag && options.abnuts[FAPU] == 0) efa_dynamics();
 if (options.abnuts[FAPU] > 0)
  {
  DV[FAMS] = DV[FAMS] - options.abnuts[FAPU] + DV[FAPU];
@@ -462,6 +465,17 @@ if (options.abnuts[FAPU] > 0)
  if (options.abnuts[EPA] > 0) DV[EPA] = options.abnuts[EPA];
  if (options.abnuts[DHA] > 0) DV[DHA] = options.abnuts[DHA];
  }
+if (options.abnuts[FAPU] == 0 && options.abnuts[AA] > 0 && options.abnuts[EPA] > 0 && options.abnuts[DHA] > 0)
+ {
+ temp = options.abnuts[AA] - DV[AA]; DV[AA] += temp; DV[OMEGA6] += temp; DV[FAPU] += temp; DV[FAMS] -= temp;
+ temp = options.abnuts[EPA] - DV[EPA]; DV[EPA] += temp; DV[OMEGA3] += temp; DV[FAPU] += temp; DV[FAMS] -= temp;
+ temp = options.abnuts[DHA] - DV[DHA]; DV[DHA] += temp; DV[OMEGA3] += temp; DV[FAPU] += temp; DV[FAMS] -= temp;
+ }
+if (options.abnuts[FAPU] == 0 && options.abnuts[LA] > 0 && options.abnuts[ALA] > 0)
+ {
+ temp1 = options.abnuts[LA] - DV[LA]; DV[LA] += temp1; DV[OMEGA6] += temp1; DV[FAPU] += temp1; DV[FAMS] -= temp1;
+ temp1 = options.abnuts[ALA] - DV[ALA]; DV[ALA] += temp1; DV[OMEGA3] += temp1; DV[FAPU] += temp1; DV[FAMS] -= temp1;
+ }
 if (options.pcsatfat > 0)
  {
  temp = DV[FASAT] + DV[FAMS];
@@ -496,20 +510,10 @@ if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN];
 if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
 else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
 temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
-if (temp > .32 && options.locknuts[LA] == 0 && options.locknuts[AA] == 0 && options.locknuts[OMEGA6] == 0 && options.locknuts[FAPU] == 0 && options.abnuts[LA] == 0 && options.abnuts[AA] == 0 && options.abnuts[OMEGA6] == 0 && options.abnuts[FAPU] == 0 ) 
- {
- temp1 = ((temp / .3) - 1);
- DV[FAMS] -= temp1 * (DV[LA] + DV[ALA]);
- DV[FAPU] += temp1 * (DV[LA] + DV[ALA]);
- DV[OMEGA6] += temp1 * DV[LA];
- DV[LA] += temp1 * DV[LA];
- DV[OMEGA3] += temp1 * DV[ALA];
- DV[ALA] += temp1 * DV[ALA];
- }
 if (temp > .32 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
  {
  temp = DV[FAMS] + DV[FASAT];
- DV[FASAT] = 0.4 * temp;
+ DV[FASAT] = temp / 3;
  DV[FAMS] = temp - DV[FASAT];
  }
 if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.fatprotratio || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
@@ -596,6 +600,7 @@ if ( !options.locknuts[PROCNT] ) options.fatprotratio = 0;
 if ( !options.locknuts[CHOCDF] ) options.pccarb = 0;
 if ( !options.locknuts[FASAT] ) options.pcsatfat = 0;
 if ( removelock ) options.autocal = 0;
+if ( removelock ) options.n6hufaspec = 0;
 for ( i = 0; i < NUTRIENT_COUNT ; i++ ) if ( !options.locknuts[i] ) options.abnuts[i] = 0;
 if ( !options.locknuts[ENERC_KCAL] ) auto_cal(&DVBase[ENERC_KCAL],removelock ? 0 : 1);
 else auto_cal(&options.abnuts[ENERC_KCAL],removelock ? 0 : 1);
@@ -675,3 +680,59 @@ while (meal_ptr->next != NULL)
   }
  }
 }
+
+void efa_dynamics()
+{
+int i;
+float temp, hufapct,calories, p3, h3, h6, p6, o;
+float target = 76;
+
+if (options.n6hufa != 0)
+ {
+ if (options.n6hufa < 15) options.n6hufa = 15;
+ if (options.n6hufa > 90) options.n6hufa = 90;
+ }
+
+options.abnuts[AA] = food_work.nutrient[AA];
+options.abnuts[LA] = food_work.nutrient[LA];
+options.abnuts[ALA] = food_work.nutrient[ALA];
+
+if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.nutrient[AA] > .02) for (i = 1; i < 200000; i++)
+ {
+ temp = i * .001;
+
+ calories = food_work.nutrient[ENERC_KCAL];
+ p3 = 902 * options.abnuts[ALA] / calories;
+ p6 = 902 * options.abnuts[LA] / calories;
+ h3 = 902 * temp / calories;
+ h6 = 902 * options.abnuts[AA] / calories;
+ o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / calories;
+ hufapct = n6hufa(p3,p6,h3,h6,o,calories);
+
+ if (options.n6hufa <= 0 && hufapct > target) continue;
+ if (options.n6hufa > 0 && hufapct > options.n6hufa) continue;
+
+ temp -= food_work.nutrient[F22D5] + food_work.nutrient[F18D4];
+ if (food_work.nutrient[EPA] > 0 || food_work.nutrient[DHA] > 0) temp = temp / (food_work.nutrient[EPA] + food_work.nutrient[DHA]);
+ options.abnuts[EPA] = food_work.nutrient[EPA] * temp;
+ options.abnuts[DHA] = food_work.nutrient[DHA] * temp;
+ return;
+ }
+else for (i = 1; i < 200000; i++)
+ {
+ temp = i * .001;
+
+ calories = food_work.nutrient[ENERC_KCAL];
+ p3 = 902 * temp / calories;
+ p6 = 902 * options.abnuts[LA] / calories;
+ h3 = 0;
+ h6 = 0;
+ o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / calories;
+ hufapct = n6hufa(p3,p6,h3,h6,o,calories);
+
+ if (options.n6hufa <= 0 && hufapct > target) continue;
+ if (options.n6hufa > 0 && hufapct > options.n6hufa) continue;
+ options.abnuts[ALA] = temp;
+ return;
+ }
+}
